@@ -32,7 +32,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 sub db {
   my $self = shift;
@@ -108,31 +108,35 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   # Create a table
   my $pg = Mojo::Pg->new('postgresql://postgres@/test');
-  $pg->db->query('create table if not exists names (name text)');
+  $pg->db->query('create table names (id serial primary key, name text)');
 
   # Insert a few rows
   my $db = $pg->db;
-  $db->query('insert into names values (?)', 'Sara');
-  $db->query('insert into names values (?)', 'Daniel');
+  $db->query('insert into names (name) values (?)', 'Sara');
+  $db->query('insert into names (name) values (?)', 'Stefan');
 
   # Insert more rows in a transaction
   {
     my $tx = $db->begin;
-    $db->query('insert into names values (?)', 'Baerbel');
-    $db->query('insert into names values (?)', 'Wolfgang');
+    $db->query('insert into names (name) values (?)', 'Baerbel');
+    $db->query('insert into names (name) values (?)', 'Wolfgang');
     $tx->commit;
   };
 
+  # Insert another row and return the generated id
+  say $db->query('insert into names (name) values (?) returning id', 'Daniel')
+    ->hash->{id};
+
+  # JSON roundtrip
+  say $db->query('select ?::json as foo', {json => {bar => 'baz'}})
+    ->expand->hash->{foo}{bar};
+
   # Select one row at a time
   my $results = $db->query('select * from names');
   while (my $next = $results->hash) {
     say $next->{name};
   }
 
-  # JSON roundtrip
-  say $db->query('select ?::json as foo', {json => {bar => 'baz'}})
-    ->expand->hash->{foo}{bar};
-
   # Select all rows blocking
   $db->query('select * from names')
     ->hashes->map(sub { $_->{name} })->join("\n")->say;
