@@ -63,7 +63,13 @@ sub listen {
 
 sub notify {
   my ($self, $name, $payload) = @_;
-  $self->query('select pg_notify($1, $2)', $name, $payload);
+
+  my $dbh    = $self->dbh;
+  my $notify = 'notify ' . $dbh->quote_identifier($name);
+  $notify .= ', ' . $dbh->quote($payload) if defined $payload;
+  $dbh->do($notify);
+  $self->_notifications;
+
   return $self;
 }
 
@@ -101,8 +107,8 @@ sub unlisten {
 
   my $dbh = $self->dbh;
   local $dbh->{AutoCommit} = 1;
-  $dbh->do('unlisten' . $dbh->quote_identifier($name));
-  $name eq '*' ? delete($self->{listen}) : delete($self->{listen}{$name});
+  $dbh->do('unlisten ' . $dbh->quote_identifier($name));
+  $name eq '*' ? delete $self->{listen} : delete $self->{listen}{$name};
   $self->_unwatch unless $self->backlog || $self->is_listening;
 
   return $self;
@@ -270,15 +276,15 @@ Check if L</"dbh"> is listening for notifications.
 
   $db = $db->listen('foo');
 
-Start listening for notifications when the L<Mojo::IOLoop> event loop is
-running.
+Subscribe to a channel and receive L</"notification"> events when the
+L<Mojo::IOLoop> event loop is running.
 
 =head2 notify
 
   $db = $db->notify('foo');
-  $db = $db->notify('foo', 'bar');
+  $db = $db->notify(foo => 'bar');
 
-Send notification with optional payload.
+Notify a channel.
 
 =head2 pid
 
@@ -312,7 +318,7 @@ results. You can also append a callback to perform operation non-blocking.
   $db = $db->unlisten('foo');
   $db = $db->unlisten('*');
 
-Stop listening for notifications.
+Unsubscribe from a channel, C<*> can be used to unsubscribe from all channels.
 
 =head1 SEE ALSO
 
